@@ -1,6 +1,6 @@
 # uWSGI build system
 
-uwsgi_version = '2.0.4'
+uwsgi_version = '2.0.5'
 
 import os
 import re
@@ -1058,7 +1058,7 @@ class uConf(object):
 
         self.embed_config = None
 
-        if uwsgi_os in ('Linux','FreeBSD'):
+        if uwsgi_os not in ('Darwin',):
             self.embed_config = os.environ.get('UWSGI_EMBED_CONFIG')
             if not self.embed_config:
                 self.embed_config = self.get('embed_config')
